@@ -3,25 +3,18 @@ import datetime
 import logging
 import threading
 import uuid
-import warnings
 from contextlib import suppress
 from inspect import isawaitable
 
 from tornado.ioloop import PeriodicCallback
 
 import dask.config
-from dask.utils import format_bytes
+from dask.utils import _deprecated, format_bytes, parse_timedelta
+from dask.widgets import get_template
 
 from ..core import Status
 from ..objects import SchedulerInfo
-from ..utils import (
-    MultiLogs,
-    format_dashboard_link,
-    log_errors,
-    parse_timedelta,
-    sync,
-    thread_state,
-)
+from ..utils import Log, Logs, format_dashboard_link, log_errors, sync, thread_state
 from .adaptive import Adaptive
 
 logger = logging.getLogger(__name__)
@@ -209,19 +202,21 @@ class Cluster:
             print(log)
 
     async def _get_logs(self, cluster=True, scheduler=True, workers=True):
-        logs = MultiLogs()
+        logs = Logs()
 
         if cluster:
-            logs["Cluster"] = self._cluster_manager_logs
+            logs["Cluster"] = Log(
+                "\n".join(line[1] for line in self._cluster_manager_logs)
+            )
 
         if scheduler:
             L = await self.scheduler_comm.get_logs()
-            logs["Scheduler"] = L
+            logs["Scheduler"] = Log("\n".join(line for level, line in L))
 
         if workers:
             d = await self.scheduler_comm.worker_logs(workers=workers)
             for k, v in d.items():
-                logs[k] = v
+                logs[k] = Log("\n".join(line for level, line in v))
 
         return logs
 
@@ -248,8 +243,8 @@ class Cluster:
             self._get_logs, cluster=cluster, scheduler=scheduler, workers=workers
         )
 
+    @_deprecated(use_instead="get_logs")
     def logs(self, *args, **kwargs):
-        warnings.warn("logs is deprecated, use get_logs instead", DeprecationWarning)
         return self.get_logs(*args, **kwargs)
 
     @property
@@ -370,54 +365,19 @@ class Cluster:
 
     def _repr_html_(self, cluster_status=None):
 
-        if not cluster_status:
-            cluster_status = ""
-
-        cluster_status += f"""
-            <tr>
-                <td style="text-align: left;">
-                    <strong>Dashboard:</strong> <a href="{self.dashboard_link}">{self.dashboard_link}</a>
-                </td>
-                <td style="text-align: left;"><strong>Workers:</strong> {len(self.scheduler_info["workers"])}</td>
-            </tr>
-            <tr>
-                <td style="text-align: left;">
-                    <strong>Total threads:</strong>
-                    {sum([w["nthreads"] for w in self.scheduler_info["workers"].values()])}
-                </td>
-                <td style="text-align: left;">
-                    <strong>Total memory:</strong>
-                    {format_bytes(sum([w["memory_limit"] for w in self.scheduler_info["workers"].values()]))}
-                </td>
-            </tr>
-        """
         try:
             scheduler_info_repr = self.scheduler_info._repr_html_()
         except AttributeError:
             scheduler_info_repr = "Scheduler not started yet."
 
-        return f"""
-            <div class="jp-RenderedHTMLCommon jp-RenderedHTML jp-mod-trusted jp-OutputArea-output">
-                <div style="
-                    width: 24px;
-                    height: 24px;
-                    background-color: #e1e1e1;
-                    border: 3px solid #9D9D9D;
-                    border-radius: 5px;
-                    position: absolute;"> </div>
-                <div style="margin-left: 48px;">
-                    <h3 style="margin-bottom: 0px; margin-top: 0px;">{type(self).__name__}</h3>
-                    <p style="color: #9D9D9D; margin-bottom: 0px;">{self.name}</p>
-                    <table style="width: 100%; text-align: left;">
-                    {cluster_status}
-                    </table>
-                    <details>
-                    <summary style="margin-bottom: 20px;"><h3 style="display: inline;">Scheduler Info</h3></summary>
-                    {scheduler_info_repr}
-                    </details>
-                </div>
-            </div>
-        """
+        return get_template("cluster.html.j2").render(
+            type=type(self).__name__,
+            name=self.name,
+            workers=self.scheduler_info["workers"],
+            dashboard_link=self.dashboard_link,
+            scheduler_info_repr=scheduler_info_repr,
+            cluster_status=cluster_status,
+        )
 
     def _ipython_display_(self, **kwargs):
         widget = self._widget()
