@@ -6,9 +6,9 @@ class MissingBokeh(RequestHandler):
     def get(self):
         with log_errors():
             self.write(
-                "<p>Dask needs bokeh >= 0.13.0 for the dashboard.</p>"
-                "<p>Install with conda: conda install bokeh>=0.13.0</p>"
-                "<p>Install with pip: pip install bokeh>=0.13.0</p>"
+                "<p>Dask needs bokeh >= 1.0 for the dashboard.</p>"
+                "<p>Install with conda: conda install bokeh>=1.0</p>"
+                "<p>Install with pip: pip install bokeh>=1.0</p>"
             )
 
 
